/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: i18n.c,v 1.9 2004/05/11 20:02:54 dom Exp $
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
    { "Start MediaMVP Server",        // English
      "Starte MediaMVP Server",       // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "MediaMVP GUI Port",            // English
      "MediaMVP GUI Port",            // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "MediaMVP Stream Port",         // English
      "MediaMVP Stream Port",         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "MediaMVP dongle.bin version",   // English
      "MediaMVP dongle.bin Version",  // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "Total Screen Width",            // English
      "Gesamte Bildschirm Breite",    // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "Total Screen Depth",            // English
      "Gesamte Bildschirm Hhe",      // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "GUI Screen Width",              // English
      "Userinterface Breite",         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "GUI Screen Depth",              // English
      "Userinterface Hhe",           // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "MediaMVP",                     // English
      "MediaMVP",                     // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Channels",                     // English
      "Kanle",                       // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Internet Radio",               // English
      "Internet Radio",               // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Other Videos",                 // English
      "Andere Videos",                // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Music",                        // English
      "Musik",                        // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Settings",                     // English
      "Einstellungen",                // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "NTSC",                         // English
      "NTSC",                         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "PAL",                          // English
      "PAL",                          // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "None",                         // English
      "Kein",                         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "Low",                           // English
      "Wenig",                        // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "Medium",                        // English
      "Mittel",                       // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "High",                         // English
      "Hoch",                         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "RGB Detected",                 // English
      "RGB Festgestellt",             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "SVideo",                       // English
      "SVideo",                       // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Composite",                    // English
      "Composite",                    // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "RGB/Composite",                // English
      "RGB/Composite",                // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "TV Mode:",                     // English
      "TV Modus:",                    // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Output:",                      // English
      "Ausgabe:",                     // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Flicker Control:",             // English
      "Flimmerkontrolle",             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Aspect Ratio:",                // English
      "Seitenverhltnis:",            // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Cancel changes",               // English
      "nderungen verwerfen",         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Save settings (may take a while)",  // English
      "Einstellungen speichern (kann etwas dauern)",  // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Play list",                    // English
      "Liste spielen",                // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Play dir",                     // English
      "Verz. spielen",                  // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Debug Level",                  // English
      "Debug Level",                  // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Pictures",                     // English
      "Bilder",                       // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "News Feeds",                   // English
      "Schlagzeilen",                 // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { "Screensaver Enabled",          // English
      "Bildschirmschoner An",         // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
   { "Switch standards",              // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      "",                             // Magyar
      "",                             // Catala
#if VDRVERSNUM >= 10300
      ""                              // Russian
#endif
    },
    { NULL }
};

const char *debug_levels[] = { "MOO", "DEBUG", "INFO", "ERROR" };
